/********************************************************************
 types.h : some internal data types for mps

 Except where otherwise indicated, all measurements are in points.
 	72 points = 1 inch
 	360 points = 127 milimeters

 Copyright (C) 1999, Richard Urena.  All rights reserved.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.   You can find the GNU
 General Public License in the file COPYING in the source directory,
 or at http://www.gnu.org

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 ********************************************************************/

#ifndef MPS__TYPES
#define MPS__TYPES

/*
 *	with the following structure we'll build a table
 *	of known fonts
*/
struct t_fontmetric {
	char   *Name;			/* symbolic name */
	char   *Face;			/* font typeface */
	float   CharWidth;		/* character width in points */
	float   PointSize;		/* font size in points */
	float	Ascend;			/* dist. from baseline to top of char. */
	float   LineSkip;		/* single-space vertical skip in points */
};


/*
 *	and with this one we'll define the known papers
*/
struct t_paperinfo {
	char *Name;
	int   Width;			/* paper width in points (portrait orientation) */
	int   Height;			/* height in points */
};


/*
 * margins
*/
struct t_marginelem {
	float Measure;
	int Units;
};

struct t_margins {
	struct t_marginelem Left;
	struct t_marginelem Right;
	struct t_marginelem Top;
	struct t_marginelem Bottom;
};


/*
 * measurement units (for the user's benefit.)
 *
*/
struct t_munits {
	float ConvFactor;	/* to convert from "Unit" to points */
	char  *Abbrev;		/* Unit's abbreviation */
};

/*
 *	data structure for error messages
*/
struct t_errmessage {
	int   ExitCode;			/* exit code as a bit flag */
	char  *Message;			/* error message, if not a system error */
};

enum t_errindex {
	MPS__ERRBADOPTION,
	MPS__ERRBADFONT,
	MPS__ERRBADPAPER,
	MPS__ERRBADPAGENO,
	MPS__ERRBADTABSTOP,
	MPS__ERRBADMARGINS,
	MPS__ERRNOMEM,
	MPS__ERRNOFILE, 
	MPS__ERRFGETS,
	MPS__LINESTRUNCATED, 
	MPS__ERRNITEMS};



#endif
